@@ -1,8 +1,9 @@
 library(wkb)
 library(sp)
-context("Conversion from WKB MultiPolygon representations")
+context("Conversion to and from WKB MultiPolygon representations")
 
 # create an object of class SpatialPolygons
+# in which one or more Polygons objects contain multiple Polygon objects
 triangle <- Polygons(
   list(
     Polygon(data.frame(x = c(2, 2.5, 3, 2), y = c(2, 3, 2, 2)))
@@ -82,6 +83,16 @@ test_that("little-endian WKB MultiPolygon representation converts to SpatialPoly
   expect_equal(obj, refobj)
 })
 
+test_that(paste(
+  "SpatialPolygons object in which one or more Polygons objects contain multiple Polygon",
+  "objects converts to little-endian WKB MultiPolygon representation"), {
+  # convert SpatialPolygons object to little-endian WKB MultiPolygon representation
+  wkb <- writeWKB(refobj)
+
+  # test
+  expect_equal(wkb, refwkb)
+})
+
 test_that("big-endian WKB MultiPolygon representation converts to SpatialPolygons object", {
   # convert big-endian WKB MultiPolygon representation to SpatialPolygons object
   obj <- readWKB(refwkbbe)
@@ -89,3 +100,14 @@ test_that("big-endian WKB MultiPolygon representation converts to SpatialPolygon
   # test
   expect_equal(obj, refobj)
 })
+
+test_that(paste(
+    "SpatialPolygons object in which one or more Polygons objects contain multiple Polygon",
+    "objects converts to big-endian WKB MultiPolygon representation"), {
+  # convert SpatialPolygons object to big-endian WKB MultiPolygon representation
+  wkbbe <- writeWKB(refobj, endian = "big")
+
+  # test
+  expect_equal(wkbbe, refwkbbe)
+})
+
